aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMarco Barisione <marco.barisione@collabora.co.uk>2013-07-26 17:44:30 +0800
committerMarco Barisione <marco.barisione@collabora.co.uk>2013-08-20 18:03:05 +0800
commitc689cd6a91cb2a31ce0d03f47e59ca4e3f368e9c (patch)
tree8d73e187743964fce43daeee6b3483abd88ab392
parent2d72679026f5f39eeffa10e474bcf151ca2002db (diff)
downloadgsoc2013-empathy-c689cd6a91cb2a31ce0d03f47e59ca4e3f368e9c.tar
gsoc2013-empathy-c689cd6a91cb2a31ce0d03f47e59ca4e3f368e9c.tar.gz
gsoc2013-empathy-c689cd6a91cb2a31ce0d03f47e59ca4e3f368e9c.tar.bz2
gsoc2013-empathy-c689cd6a91cb2a31ce0d03f47e59ca4e3f368e9c.tar.lz
gsoc2013-empathy-c689cd6a91cb2a31ce0d03f47e59ca4e3f368e9c.tar.xz
gsoc2013-empathy-c689cd6a91cb2a31ce0d03f47e59ca4e3f368e9c.tar.zst
gsoc2013-empathy-c689cd6a91cb2a31ce0d03f47e59ca4e3f368e9c.zip
uoa-utils: move from Empathy to tp-aw
https://bugzilla.gnome.org/show_bug.cgi?id=699492
-rw-r--r--libempathy/Makefile.am2
-rw-r--r--libempathy/empathy-uoa-auth-handler.c2
-rw-r--r--tp-account-widgets/Makefile.am16
-rw-r--r--tp-account-widgets/tpaw-keyring.c6
-rw-r--r--tp-account-widgets/tpaw-uoa-utils.c (renamed from libempathy/empathy-uoa-utils.c)10
-rw-r--r--tp-account-widgets/tpaw-uoa-utils.h (renamed from libempathy/empathy-uoa-utils.h)14
6 files changed, 31 insertions, 19 deletions
diff --git a/libempathy/Makefile.am b/libempathy/Makefile.am
index faf647a4c..d80c39523 100644
--- a/libempathy/Makefile.am
+++ b/libempathy/Makefile.am
@@ -93,8 +93,6 @@ goa_sources = \
uoa_sources = \
empathy-uoa-auth-handler.c \
empathy-uoa-auth-handler.h \
- empathy-uoa-utils.c \
- empathy-uoa-utils.h \
$(NULL)
pkglib_LTLIBRARIES = libempathy.la
diff --git a/libempathy/empathy-uoa-auth-handler.c b/libempathy/empathy-uoa-auth-handler.c
index eff3dd6d4..d5a6577c2 100644
--- a/libempathy/empathy-uoa-auth-handler.c
+++ b/libempathy/empathy-uoa-auth-handler.c
@@ -31,9 +31,9 @@
#include <libsignon-glib/signon-auth-session.h>
#include <tp-account-widgets/tpaw-keyring.h>
+#include <tp-account-widgets/tpaw-uoa-utils.h>
#include "empathy-utils.h"
-#include "empathy-uoa-utils.h"
#include "empathy-sasl-mechanisms.h"
#define DEBUG_FLAG EMPATHY_DEBUG_SASL
diff --git a/tp-account-widgets/Makefile.am b/tp-account-widgets/Makefile.am
index dbfffeeb5..80089458f 100644
--- a/tp-account-widgets/Makefile.am
+++ b/tp-account-widgets/Makefile.am
@@ -63,6 +63,19 @@ libtp_account_widgets_la_SOURCES = \
$(libtp_account_widgets_headers) \
$(NULL)
+# these are sources that depend on Ubuntu Online Accounts
+uoa_sources = \
+ tpaw-uoa-utils.c \
+ tpaw-uoa-utils.h \
+ $(NULL)
+
+if HAVE_UOA
+libtp_account_widgets_la_SOURCES += $(uoa_sources)
+EXTRA_DIST =
+else
+EXTRA_DIST = $(uoa_sources)
+endif
+
# do not distribute generated files
nodist_libtp_account_widgets_la_SOURCES = \
$(BUILT_SOURCES)
@@ -70,6 +83,7 @@ nodist_libtp_account_widgets_la_SOURCES = \
check_c_sources = \
$(libtp_account_widgets_sources) \
$(libtp_account_widgets_headers) \
+ $(uoa_sources) \
$(NULL)
include $(top_srcdir)/tools/check-coding-style.mk
check-local: check-coding-style
@@ -103,7 +117,7 @@ tpaw-account-widgets-resources.c: tpaw-account-widgets.gresource.xml $(account_w
tpaw-account-widgets-resources.h: tpaw-account-widgets.gresource.xml $(account_widgets_resource_files)
$(AM_V_GEN)$(GLIB_COMPILE_RESOURCES) --target=$@ --sourcedir=$(srcdir) --generate-header $<
-EXTRA_DIST = \
+EXTRA_DIST += \
tpaw-account-widgets.gresource.xml \
$(account_widgets_dtd_files) \
$(account_widgets_ui_files) \
diff --git a/tp-account-widgets/tpaw-keyring.c b/tp-account-widgets/tpaw-keyring.c
index 827f2ca6c..94bbd93e0 100644
--- a/tp-account-widgets/tpaw-keyring.c
+++ b/tp-account-widgets/tpaw-keyring.c
@@ -29,7 +29,7 @@
#include <libaccounts-glib/ag-manager.h>
#include <libaccounts-glib/ag-service.h>
#include <libsignon-glib/signon-identity.h>
-#include "empathy-uoa-utils.h"
+#include "tpaw-uoa-utils.h"
#endif
#include "empathy-utils.h"
@@ -114,11 +114,11 @@ uoa_password_common (TpAccount *tp_account,
goto error;
}
- manager = empathy_uoa_manager_dup ();
+ manager = tpaw_uoa_manager_dup ();
account = ag_manager_get_account (manager, account_id);
/* Assuming there is only one IM service */
- l = ag_account_list_services_by_type (account, EMPATHY_UOA_SERVICE_TYPE);
+ l = ag_account_list_services_by_type (account, TPAW_UOA_SERVICE_TYPE);
if (l == NULL)
{
g_simple_async_result_set_error (result,
diff --git a/libempathy/empathy-uoa-utils.c b/tp-account-widgets/tpaw-uoa-utils.c
index 6032d36bd..6eb43fe1f 100644
--- a/libempathy/empathy-uoa-utils.c
+++ b/tp-account-widgets/tpaw-uoa-utils.c
@@ -1,5 +1,5 @@
/*
* empathy-uoa-utils.c - Source for UOA utilities
* Copyright (C) 2012 Collabora Ltd.
* @author Xavier Claessens <xavier.claessens@collabora.co.uk>
*
@@ -19,7 +19,7 @@
*/
#include "config.h"
-#include "empathy-uoa-utils.h"
+#include "tpaw-uoa-utils.h"
#define DEBUG_FLAG EMPATHY_DEBUG_ACCOUNT
#include "empathy-debug.h"
@@ -27,7 +27,7 @@
static AgManager *singleton = NULL;
void
-empathy_uoa_manager_set_default (AgManager *manager)
+tpaw_uoa_manager_set_default (AgManager *manager)
{
if (singleton != NULL)
return;
@@ -37,12 +37,12 @@ empathy_uoa_manager_set_default (AgManager *manager)
}
AgManager *
-empathy_uoa_manager_dup (void)
+tpaw_uoa_manager_dup (void)
{
if (singleton != NULL)
return g_object_ref (singleton);
- singleton = ag_manager_new_for_service_type (EMPATHY_UOA_SERVICE_TYPE);
+ singleton = ag_manager_new_for_service_type (TPAW_UOA_SERVICE_TYPE);
g_object_add_weak_pointer ((GObject *) singleton, (gpointer) &singleton);
return singleton;
@@ -1,5 +1,5 @@
/*
- * empathy-uoa-utils.c - Source for UOA utilities
+ * tpaw-uoa-utils.c - Source for UOA utilities
* Copyright (C) 2012 Collabora Ltd.
* @author Xavier Claessens <xavier.claessens@collabora.co.uk>
diff --git a/libempathy/empathy-uoa-utils.h b/tp-account-widgets/tpaw-uoa-utils.h
index 2cd7a41a2..3529e1ae2 100644
--- a/libempathy/empathy-uoa-utils.h
+++ b/tp-account-widgets/tpaw-uoa-utils.h
@@ -1,5 +1,5 @@
/*
* empathy-utils.h - Header for UOA utilities
* Copyright (C) 2012 Collabora Ltd.
* @author Xavier Claessens <xavier.claessens@collabora.co.uk>
*
@@ -18,18 +18,18 @@
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
-#ifndef __EMPATHY_UOA_UTILS_H__
-#define __EMPATHY_UOA_UTILS_H__
+#ifndef __TPAW_UOA_UTILS_H__
+#define __TPAW_UOA_UTILS_H__
#include <libaccounts-glib/ag-manager.h>
-#define EMPATHY_UOA_SERVICE_TYPE "IM"
+#define TPAW_UOA_SERVICE_TYPE "IM"
G_BEGIN_DECLS
-void empathy_uoa_manager_set_default (AgManager *manager);
-AgManager *empathy_uoa_manager_dup (void);
+void tpaw_uoa_manager_set_default (AgManager *manager);
+AgManager *tpaw_uoa_manager_dup (void);
G_END_DECLS
-#endif /* #ifndef __EMPATHY_UOA_UTILS_H__*/
+#endif /* #ifndef __TPAW_UOA_UTILS_H__*/
@@ -1,5 +1,5 @@
/*
- * empathy-utils.h - Header for UOA utilities
+ * tpaw-utils.h - Header for UOA utilities
* Copyright (C) 2012 Collabora Ltd.
* @author Xavier Claessens <xavier.claessens@collabora.co.uk>